All pastes #614941 Raw Edit

Something

public text v1 · immutable
·published 2007-07-11 21:22 UTC
rendered paste body
Running aclocal...
Running autoheader...
Running autoconf...
Running libtoolize...
Running automake...
configure.in:4: installing `./missing'
configure.in:4: installing `./install-sh'
src/bin/Makefile.am: installing `./depcomp'
 * Removing useless C++ checks ...                                        [ ok ]
 * Running elibtoolize in: e17/libs/esmart
 *   Applying sed-1.5.6.patch ...
 * econf: updating e17/libs/esmart/config.sub with /usr/share/gnuconfig/config.sub
 * econf: updating e17/libs/esmart/config.guess with /usr/share/gnuconfig/config.guess
./configure --prefix=/usr --host=i686-pc-linux-gnu --mandir=/usr/share/man --infodir=/usr/share/info --datadir=/usr/share --sysconfdir=/etc --localstatedir=/var/lib --build=i686-pc-linux-gnu
checking for a BSD-compatible install... /usr/bin/install -c
checking whether build environment is sane... yes
checking for a thread-safe mkdir -p... /bin/mkdir -p
checking for gawk... gawk
checking whether make sets $(MAKE)... yes
checking for style of include used by make... GNU
checking for i686-pc-linux-gnu-gcc... i686-pc-linux-gnu-gcc
checking for C compiler default output file name... a.out
checking whether the C compiler works... yes
checking whether we are cross compiling... no
checking for suffix of executables...
checking for suffix of object files... o
checking whether we are using the GNU C compiler... yes
checking whether i686-pc-linux-gnu-gcc accepts -g... yes
checking for i686-pc-linux-gnu-gcc option to accept ISO C89... none needed
checking dependency style of i686-pc-linux-gnu-gcc... gcc3
checking for library containing strerror... none required
checking for i686-pc-linux-gnu-gcc... (cached) i686-pc-linux-gnu-gcc
checking whether we are using the GNU C compiler... (cached) yes
checking whether i686-pc-linux-gnu-gcc accepts -g... (cached) yes
checking for i686-pc-linux-gnu-gcc option to accept ISO C89... (cached) none needed
checking dependency style of i686-pc-linux-gnu-gcc... (cached) gcc3
checking for i686-pc-linux-gnu-gcc... (cached) i686-pc-linux-gnu-gcc
checking whether we are using the GNU C compiler... (cached) yes
checking whether i686-pc-linux-gnu-gcc accepts -g... (cached) yes
checking for i686-pc-linux-gnu-gcc option to accept ISO C89... (cached) none needed
checking dependency style of i686-pc-linux-gnu-gcc... (cached) gcc3
checking how to run the C preprocessor... i686-pc-linux-gnu-gcc -E
checking for grep that handles long lines and -e... /bin/grep
checking for egrep... /bin/grep -E
checking for ANSI C header files... yes
checking for sys/types.h... yes
checking for sys/stat.h... yes
checking for stdlib.h... yes
checking for string.h... yes
checking for memory.h... yes
checking for strings.h... yes
checking for inttypes.h... yes
checking for stdint.h... yes
checking for unistd.h... yes
checking whether byte ordering is bigendian... no
checking for an ANSI C-conforming const... yes
checking build system type... i686-pc-linux-gnu
checking host system type... i686-pc-linux-gnu
checking for a sed that does not truncate output... /bin/sed
checking for ld used by i686-pc-linux-gnu-gcc... /usr/i686-pc-linux-gnu/bin/ld
checking if the linker (/usr/i686-pc-linux-gnu/bin/ld) is GNU ld... yes
checking for /usr/i686-pc-linux-gnu/bin/ld option to reload object files... -r
checking for BSD-compatible nm... /usr/bin/nm -B
checking whether ln -s works... yes
checking how to recognize dependent libraries... pass_all
checking dlfcn.h usability... yes
checking dlfcn.h presence... yes
checking for dlfcn.h... yes
checking for i686-pc-linux-gnu-g++... i686-pc-linux-gnu-g++
checking whether we are using the GNU C++ compiler... yes
checking whether i686-pc-linux-gnu-g++ accepts -g... yes
checking dependency style of i686-pc-linux-gnu-g++... gcc3
checking how to run the C++ preprocessor... i686-pc-linux-gnu-g++ -E
checking for i686-pc-linux-gnu-g77... no
checking for i686-pc-linux-gnu-xlf... no
checking for i686-pc-linux-gnu-f77... no
checking for i686-pc-linux-gnu-frt... no
checking for i686-pc-linux-gnu-pgf77... no
checking for i686-pc-linux-gnu-cf77... no
checking for i686-pc-linux-gnu-fort77... no
checking for i686-pc-linux-gnu-fl32... no
checking for i686-pc-linux-gnu-af77... no
checking for i686-pc-linux-gnu-xlf90... no
checking for i686-pc-linux-gnu-f90... no
checking for i686-pc-linux-gnu-pgf90... no
checking for i686-pc-linux-gnu-pghpf... no
checking for i686-pc-linux-gnu-epcf90... no
checking for i686-pc-linux-gnu-gfortran... i686-pc-linux-gnu-gfortran
checking whether we are using the GNU Fortran 77 compiler... yes
checking whether i686-pc-linux-gnu-gfortran accepts -g... yes
checking the maximum length of command line arguments... 32768
checking command to parse /usr/bin/nm -B output from i686-pc-linux-gnu-gcc object... ok
checking for objdir... .libs
checking for i686-pc-linux-gnu-ar... i686-pc-linux-gnu-ar
checking for i686-pc-linux-gnu-ranlib... i686-pc-linux-gnu-ranlib
checking for i686-pc-linux-gnu-strip... i686-pc-linux-gnu-strip
checking for correct ltmain.sh version... yes
checking if i686-pc-linux-gnu-gcc supports -fno-rtti -fno-exceptions... no
checking for i686-pc-linux-gnu-gcc option to produce PIC... -fPIC
checking if i686-pc-linux-gnu-gcc PIC flag -fPIC works... yes
checking if i686-pc-linux-gnu-gcc static flag -static works... yes
checking if i686-pc-linux-gnu-gcc supports -c -o file.o... yes
checking whether the i686-pc-linux-gnu-gcc linker (/usr/i686-pc-linux-gnu/bin/ld) supports shared libraries... yes
checking whether -lc should be explicitly linked in... no
checking dynamic linker characteristics... GNU/Linux ld.so
checking how to hardcode library paths into programs... immediate
checking whether stripping libraries is possible... yes
checking if libtool supports shared libraries... yes
checking whether to build shared libraries... yes
checking whether to build static libraries... yes
configure: creating libtool
appending configuration tag "CXX" to libtool
checking for ld used by i686-pc-linux-gnu-g++... /usr/i686-pc-linux-gnu/bin/ld
checking if the linker (/usr/i686-pc-linux-gnu/bin/ld) is GNU ld... yes
checking whether the i686-pc-linux-gnu-g++ linker (/usr/i686-pc-linux-gnu/bin/ld) supports shared libraries... yes
checking for i686-pc-linux-gnu-g++ option to produce PIC... -fPIC
checking if i686-pc-linux-gnu-g++ PIC flag -fPIC works... yes
checking if i686-pc-linux-gnu-g++ static flag -static works... yes
checking if i686-pc-linux-gnu-g++ supports -c -o file.o... yes
checking whether the i686-pc-linux-gnu-g++ linker (/usr/i686-pc-linux-gnu/bin/ld) supports shared libraries... yes
checking dynamic linker characteristics... GNU/Linux ld.so
checking how to hardcode library paths into programs... immediate
appending configuration tag "F77" to libtool
checking if libtool supports shared libraries... yes
checking whether to build shared libraries... yes
checking whether to build static libraries... yes
checking for i686-pc-linux-gnu-gfortran option to produce PIC... -fPIC
checking if i686-pc-linux-gnu-gfortran PIC flag -fPIC works... yes
checking if i686-pc-linux-gnu-gfortran static flag -static works... yes
checking if i686-pc-linux-gnu-gfortran supports -c -o file.o... yes
checking whether the i686-pc-linux-gnu-gfortran linker (/usr/i686-pc-linux-gnu/bin/ld) supports shared libraries... yes
checking dynamic linker characteristics... GNU/Linux ld.so
checking how to hardcode library paths into programs... immediate
checking for i686-pc-linux-gnu-pkg-config... no
checking for pkg-config... /usr/bin/pkg-config
checking pkg-config is at least version 0.9.0... yes
checking for CONTAINER... yes
checking ltdl.h usability... yes
checking ltdl.h presence... yes
checking for ltdl.h... yes
checking for DRAGGIES... yes
checking for RESIZE... yes
checking for TRANSX11... yes
checking for THUMB... yes
checking for TEXT_ENTRY... yes
checking for FILE_DIALOG... yes
checking for perl... /usr/bin/perl
configure: creating ./config.status
config.status: creating Makefile
config.status: creating esmart_container.pc
config.status: creating esmart_draggies.pc
config.status: creating esmart_file_dialog.pc
config.status: creating esmart_resize.pc
config.status: creating esmart_textarea.pc
config.status: creating esmart_text_entry.pc
config.status: creating esmart_thumb.pc
config.status: creating esmart_trans_x11.pc
config.status: creating esmart.spec
config.status: creating src/Makefile
config.status: creating src/lib/Makefile
config.status: creating src/lib/esmart_container/Makefile
config.status: creating src/lib/esmart_container/layout/Makefile
config.status: creating src/lib/esmart_container/layout/default/Makefile
config.status: creating src/lib/esmart_container/layout/entice/Makefile
config.status: creating src/lib/esmart_container/layout/engage/Makefile
config.status: creating src/lib/esmart_text_entry/Makefile
config.status: creating src/lib/esmart_file_dialog/Makefile
config.status: creating src/lib/esmart_thumb/Makefile
config.status: creating src/lib/esmart_trans_x11/Makefile
config.status: creating src/lib/esmart_draggies/Makefile
config.status: creating src/lib/esmart_resize/Makefile
config.status: creating src/bin/Makefile
config.status: creating data/Makefile
config.status: creating data/images/Makefile
config.status: creating debian/changelog
config.status: creating src/config.h
config.status: executing depfiles commands



------------------------------------------------------------------------
esmart 0.9.0.010
------------------------------------------------------------------------

Configuration Options Summary:

Components:
  Container...............: yes
  Draggies................: yes
  Resize..................: yes
  File Dialog.............: no
  Text Entry..............: yes
  Text Area...............: no
  Thumb...................: yes
  Trans X11...............: yes

------------------------------------------------

Now type 'make' ('gmake' on some systems) to compile esmart,
and then afterwards as root (or the user who will install this), type
'make install'. Change users with 'su' or 'sudo' appropriately.

Making all in src
make[1]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src'
make  all-recursive
make[2]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src'
Making all in lib
make[3]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib'
Making all in esmart_container
make[4]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container'
Making all in layout
make[5]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container/layout'
Making all in default
make[6]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container/layout/default'
/bin/sh ../../../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../../../src -I../../../../../src/lib/esmart_container     -march=i686 -O2 -pipe -Wall  -MT default.lo -MD -MP -MF .deps/default.Tpo -c -o default.lo default.c
mkdir .libs
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../../../src -I../../../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT default.lo -MD -MP -MF .deps/default.Tpo -c default.c  -fPIC -DPIC -o .libs/default.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../../../src -I../../../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT default.lo -MD -MP -MF .deps/default.Tpo -c default.c -o default.o >/dev/null 2>&1
mv -f .deps/default.Tpo .deps/default.Plo
/bin/sh ../../../../../libtool --tag=CC   --mode=link i686-pc-linux-gnu-gcc  -march=i686 -O2 -pipe -Wall  -module -avoid-version  -o default.la -rpath /usr/lib/esmart/layout default.lo
i686-pc-linux-gnu-gcc -shared  .libs/default.o   -march=i686 -Wl,-soname -Wl,default.so -o .libs/default.so
i686-pc-linux-gnu-ar cru .libs/default.a  default.o
i686-pc-linux-gnu-ranlib .libs/default.a
creating default.la
(cd .libs && rm -f default.la && ln -s ../default.la default.la)
make[6]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container/layout/default'
Making all in engage
make[6]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container/layout/engage'
/bin/sh ../../../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../../../src -I../../../../../src/lib/esmart_container     -march=i686 -O2 -pipe -Wall  -MT engage.lo -MD -MP -MF .deps/engage.Tpo -c -o engage.lo engage.c
mkdir .libs
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../../../src -I../../../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT engage.lo -MD -MP -MF .deps/engage.Tpo -c engage.c  -fPIC -DPIC -o .libs/engage.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../../../src -I../../../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT engage.lo -MD -MP -MF .deps/engage.Tpo -c engage.c -o engage.o >/dev/null 2>&1
mv -f .deps/engage.Tpo .deps/engage.Plo
/bin/sh ../../../../../libtool --tag=CC   --mode=link i686-pc-linux-gnu-gcc  -march=i686 -O2 -pipe -Wall  -module -avoid-version  -o engage.la -rpath /usr/lib/esmart/layout engage.lo
i686-pc-linux-gnu-gcc -shared  .libs/engage.o   -march=i686 -Wl,-soname -Wl,engage.so -o .libs/engage.so
i686-pc-linux-gnu-ar cru .libs/engage.a  engage.o
i686-pc-linux-gnu-ranlib .libs/engage.a
creating engage.la
(cd .libs && rm -f engage.la && ln -s ../engage.la engage.la)
make[6]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container/layout/engage'
Making all in entice
make[6]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container/layout/entice'
/bin/sh ../../../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../../../src -I../../../../../src/lib/esmart_container     -march=i686 -O2 -pipe -Wall  -MT entice.lo -MD -MP -MF .deps/entice.Tpo -c -o entice.lo entice.c
mkdir .libs
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../../../src -I../../../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT entice.lo -MD -MP -MF .deps/entice.Tpo -c entice.c  -fPIC -DPIC -o .libs/entice.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../../../src -I../../../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT entice.lo -MD -MP -MF .deps/entice.Tpo -c entice.c -o entice.o >/dev/null 2>&1
mv -f .deps/entice.Tpo .deps/entice.Plo
/bin/sh ../../../../../libtool --tag=CC   --mode=link i686-pc-linux-gnu-gcc  -march=i686 -O2 -pipe -Wall  -module -avoid-version  -o entice.la -rpath /usr/lib/esmart/layout entice.lo
i686-pc-linux-gnu-gcc -shared  .libs/entice.o   -march=i686 -Wl,-soname -Wl,entice.so -o .libs/entice.so
i686-pc-linux-gnu-ar cru .libs/entice.a  entice.o
i686-pc-linux-gnu-ranlib .libs/entice.a
creating entice.la
(cd .libs && rm -f entice.la && ln -s ../entice.la entice.la)
make[6]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container/layout/entice'
make[6]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container/layout'
make[6]: Nothing to be done for `all-am'.
make[6]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container/layout'
make[5]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container/layout'
make[5]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container'
/bin/sh ../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container     -march=i686 -O2 -pipe -Wall  -MT esmart_container.lo -MD -MP -MF .deps/esmart_container.Tpo -c -o esmart_container.lo esmart_container.c
mkdir .libs
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT esmart_container.lo -MD -MP -MF .deps/esmart_container.Tpo -c esmart_container.c  -fPIC -DPIC -o .libs/esmart_container.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT esmart_container.lo -MD -MP -MF .deps/esmart_container.Tpo -c esmart_container.c -o esmart_container.o >/dev/null 2>&1
mv -f .deps/esmart_container.Tpo .deps/esmart_container.Plo
/bin/sh ../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container     -march=i686 -O2 -pipe -Wall  -MT esmart_container_element.lo -MD -MP -MF .deps/esmart_container_element.Tpo -c -o esmart_container_element.lo esmart_container_element.c
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT esmart_container_element.lo -MD -MP -MF .deps/esmart_container_element.Tpo -c esmart_container_element.c  -fPIC -DPIC -o .libs/esmart_container_element.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT esmart_container_element.lo -MD -MP -MF .deps/esmart_container_element.Tpo -c esmart_container_element.c -o esmart_container_element.o >/dev/null 2>&1
mv -f .deps/esmart_container_element.Tpo .deps/esmart_container_element.Plo
/bin/sh ../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container     -march=i686 -O2 -pipe -Wall  -MT esmart_container_plugin.lo -MD -MP -MF .deps/esmart_container_plugin.Tpo -c -o esmart_container_plugin.lo esmart_container_plugin.c
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT esmart_container_plugin.lo -MD -MP -MF .deps/esmart_container_plugin.Tpo -c esmart_container_plugin.c  -fPIC -DPIC -o .libs/esmart_container_plugin.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT esmart_container_plugin.lo -MD -MP -MF .deps/esmart_container_plugin.Tpo -c esmart_container_plugin.c -o esmart_container_plugin.o >/dev/null 2>&1
mv -f .deps/esmart_container_plugin.Tpo .deps/esmart_container_plugin.Plo
/bin/sh ../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container     -march=i686 -O2 -pipe -Wall  -MT esmart_container_smart.lo -MD -MP -MF .deps/esmart_container_smart.Tpo -c -o esmart_container_smart.lo esmart_container_smart.c
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT esmart_container_smart.lo -MD -MP -MF .deps/esmart_container_smart.Tpo -c esmart_container_smart.c  -fPIC -DPIC -o .libs/esmart_container_smart.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT esmart_container_smart.lo -MD -MP -MF .deps/esmart_container_smart.Tpo -c esmart_container_smart.c -o esmart_container_smart.o >/dev/null 2>&1
mv -f .deps/esmart_container_smart.Tpo .deps/esmart_container_smart.Plo
/bin/sh ../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container     -march=i686 -O2 -pipe -Wall  -MT esmart_container_util.lo -MD -MP -MF .deps/esmart_container_util.Tpo -c -o esmart_container_util.lo esmart_container_util.c
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT esmart_container_util.lo -MD -MP -MF .deps/esmart_container_util.Tpo -c esmart_container_util.c  -fPIC -DPIC -o .libs/esmart_container_util.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_container -march=i686 -O2 -pipe -Wall -MT esmart_container_util.lo -MD -MP -MF .deps/esmart_container_util.Tpo -c esmart_container_util.c -o esmart_container_util.o >/dev/null 2>&1
mv -f .deps/esmart_container_util.Tpo .deps/esmart_container_util.Plo
/bin/sh ../../../libtool --tag=CC   --mode=link i686-pc-linux-gnu-gcc  -march=i686 -O2 -pipe -Wall  -levas   -version-info 0:9:0   -o libesmart_container.la -rpath /usr/lib esmart_container.lo esmart_container_element.lo esmart_container_plugin.lo esmart_container_smart.lo esmart_container_util.lo -lltdl -lm
i686-pc-linux-gnu-gcc -shared  .libs/esmart_container.o .libs/esmart_container_element.o .libs/esmart_container_plugin.o .libs/esmart_container_smart.o .libs/esmart_container_util.o  /usr/lib/libevas.so -L/usr/lib /usr/lib/libltdl.so -lm  -march=i686 -Wl,-soname -Wl,libesmart_container.so.0 -o .libs/libesmart_container.so.0.0.9
(cd .libs && rm -f libesmart_container.so.0 && ln -s libesmart_container.so.0.0.9 libesmart_container.so.0)
(cd .libs && rm -f libesmart_container.so && ln -s libesmart_container.so.0.0.9 libesmart_container.so)
i686-pc-linux-gnu-ar cru .libs/libesmart_container.a  esmart_container.o esmart_container_element.o esmart_container_plugin.o esmart_container_smart.o esmart_container_util.o
i686-pc-linux-gnu-ranlib .libs/libesmart_container.a
creating libesmart_container.la
(cd .libs && rm -f libesmart_container.la && ln -s ../libesmart_container.la libesmart_container.la)
make[5]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container'
make[4]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_container'
Making all in esmart_draggies
make[4]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_draggies'
/bin/sh ../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_draggies     -march=i686 -O2 -pipe -Wall  -MT esmart_draggies.lo -MD -MP -MF .deps/esmart_draggies.Tpo -c -o esmart_draggies.lo esmart_draggies.c
mkdir .libs
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_draggies -march=i686 -O2 -pipe -Wall -MT esmart_draggies.lo -MD -MP -MF .deps/esmart_draggies.Tpo -c esmart_draggies.c  -fPIC -DPIC -o .libs/esmart_draggies.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_draggies -march=i686 -O2 -pipe -Wall -MT esmart_draggies.lo -MD -MP -MF .deps/esmart_draggies.Tpo -c esmart_draggies.c -o esmart_draggies.o >/dev/null 2>&1
mv -f .deps/esmart_draggies.Tpo .deps/esmart_draggies.Plo
/bin/sh ../../../libtool --tag=CC   --mode=link i686-pc-linux-gnu-gcc  -march=i686 -O2 -pipe -Wall  -lecore_evas -lecore -levas -lecore_x   -version-info 0:9:0  -o libesmart_draggies.la -rpath /usr/lib esmart_draggies.lo
i686-pc-linux-gnu-gcc -shared  .libs/esmart_draggies.o  /usr/lib/libecore_evas.so -L/usr/lib -L/usr/X11R6/lib /usr/lib/libecore.so /usr/lib/libevas.so /usr/lib/libecore_x.so  -march=i686 -Wl,-soname -Wl,libesmart_draggies.so.0 -o .libs/libesmart_draggies.so.0.0.9
(cd .libs && rm -f libesmart_draggies.so.0 && ln -s libesmart_draggies.so.0.0.9 libesmart_draggies.so.0)
(cd .libs && rm -f libesmart_draggies.so && ln -s libesmart_draggies.so.0.0.9 libesmart_draggies.so)
i686-pc-linux-gnu-ar cru .libs/libesmart_draggies.a  esmart_draggies.o
i686-pc-linux-gnu-ranlib .libs/libesmart_draggies.a
creating libesmart_draggies.la
(cd .libs && rm -f libesmart_draggies.la && ln -s ../libesmart_draggies.la libesmart_draggies.la)
make[4]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_draggies'
Making all in esmart_text_entry
make[4]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_text_entry'
/bin/sh ../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_text_entry     -march=i686 -O2 -pipe -Wall  -MT esmart_text_entry.lo -MD -MP -MF .deps/esmart_text_entry.Tpo -c -o esmart_text_entry.lo esmart_text_entry.c
mkdir .libs
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_text_entry -march=i686 -O2 -pipe -Wall -MT esmart_text_entry.lo -MD -MP -MF .deps/esmart_text_entry.Tpo -c esmart_text_entry.c  -fPIC -DPIC -o .libs/esmart_text_entry.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_text_entry -march=i686 -O2 -pipe -Wall -MT esmart_text_entry.lo -MD -MP -MF .deps/esmart_text_entry.Tpo -c esmart_text_entry.c -o esmart_text_entry.o >/dev/null 2>&1
mv -f .deps/esmart_text_entry.Tpo .deps/esmart_text_entry.Plo
/bin/sh ../../../libtool --tag=CC   --mode=link i686-pc-linux-gnu-gcc  -march=i686 -O2 -pipe -Wall  -ledje -levas   -version-info 0:9:0  -o libesmart_text_entry.la -rpath /usr/lib esmart_text_entry.lo
i686-pc-linux-gnu-gcc -shared  .libs/esmart_text_entry.o  /usr/lib/libedje.so -L/usr/lib -L/usr/X11R6/lib /usr/lib/libevas.so  -march=i686 -Wl,-soname -Wl,libesmart_text_entry.so.0 -o .libs/libesmart_text_entry.so.0.0.9
(cd .libs && rm -f libesmart_text_entry.so.0 && ln -s libesmart_text_entry.so.0.0.9 libesmart_text_entry.so.0)
(cd .libs && rm -f libesmart_text_entry.so && ln -s libesmart_text_entry.so.0.0.9 libesmart_text_entry.so)
i686-pc-linux-gnu-ar cru .libs/libesmart_text_entry.a  esmart_text_entry.o
i686-pc-linux-gnu-ranlib .libs/libesmart_text_entry.a
creating libesmart_text_entry.la
(cd .libs && rm -f libesmart_text_entry.la && ln -s ../libesmart_text_entry.la libesmart_text_entry.la)
make[4]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_text_entry'
Making all in esmart_thumb
make[4]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_thumb'
/bin/sh ../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_thumb     -march=i686 -O2 -pipe -Wall  -MT esmart_thumb.lo -MD -MP -MF .deps/esmart_thumb.Tpo -c -o esmart_thumb.lo esmart_thumb.c
mkdir .libs
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_thumb -march=i686 -O2 -pipe -Wall -MT esmart_thumb.lo -MD -MP -MF .deps/esmart_thumb.Tpo -c esmart_thumb.c  -fPIC -DPIC -o .libs/esmart_thumb.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_thumb -march=i686 -O2 -pipe -Wall -MT esmart_thumb.lo -MD -MP -MF .deps/esmart_thumb.Tpo -c esmart_thumb.c -o esmart_thumb.o >/dev/null 2>&1
mv -f .deps/esmart_thumb.Tpo .deps/esmart_thumb.Plo
/bin/sh ../../../libtool --tag=CC   --mode=link i686-pc-linux-gnu-gcc  -march=i686 -O2 -pipe -Wall  -levas -lImlib2 -lepsilon   -version-info 0:9:0  -o libesmart_thumb.la -rpath /usr/lib esmart_thumb.lo
i686-pc-linux-gnu-gcc -shared  .libs/esmart_thumb.o  /usr/lib/libevas.so -L/usr/lib /usr/lib/libImlib2.so -L/usr/X11R6/lib /usr/lib/libepsilon.so  -march=i686 -Wl,-soname -Wl,libesmart_thumb.so.0 -o .libs/libesmart_thumb.so.0.0.9
(cd .libs && rm -f libesmart_thumb.so.0 && ln -s libesmart_thumb.so.0.0.9 libesmart_thumb.so.0)
(cd .libs && rm -f libesmart_thumb.so && ln -s libesmart_thumb.so.0.0.9 libesmart_thumb.so)
i686-pc-linux-gnu-ar cru .libs/libesmart_thumb.a  esmart_thumb.o
i686-pc-linux-gnu-ranlib .libs/libesmart_thumb.a
creating libesmart_thumb.la
(cd .libs && rm -f libesmart_thumb.la && ln -s ../libesmart_thumb.la libesmart_thumb.la)
make[4]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_thumb'
Making all in esmart_trans_x11
make[4]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_trans_x11'
/bin/sh ../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_trans_x11     -march=i686 -O2 -pipe -Wall  -MT esmart_trans_x11.lo -MD -MP -MF .deps/esmart_trans_x11.Tpo -c -o esmart_trans_x11.lo esmart_trans_x11.c
mkdir .libs
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_trans_x11 -march=i686 -O2 -pipe -Wall -MT esmart_trans_x11.lo -MD -MP -MF .deps/esmart_trans_x11.Tpo -c esmart_trans_x11.c  -fPIC -DPIC -o .libs/esmart_trans_x11.o
esmart_trans_x11.c: In function '_esmart_trans_x11_pixmap_get':
esmart_trans_x11.c:183: warning: pointer targets in passing argument 4 of 'ecore_x_pixmap_geometry_get' differ in signedness
esmart_trans_x11.c:183: warning: pointer targets in passing argument 5 of 'ecore_x_pixmap_geometry_get' differ in signedness
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_trans_x11 -march=i686 -O2 -pipe -Wall -MT esmart_trans_x11.lo -MD -MP -MF .deps/esmart_trans_x11.Tpo -c esmart_trans_x11.c -o esmart_trans_x11.o >/dev/null 2>&1
mv -f .deps/esmart_trans_x11.Tpo .deps/esmart_trans_x11.Plo
/bin/sh ../../../libtool --tag=CC   --mode=link i686-pc-linux-gnu-gcc  -march=i686 -O2 -pipe -Wall  -levas -lecore_x -lImlib2   -version-info 0:9:0 -L/usr/X11R6/lib  -o libesmart_trans_x11.la -rpath /usr/lib esmart_trans_x11.lo
i686-pc-linux-gnu-gcc -shared  .libs/esmart_trans_x11.o  /usr/lib/libevas.so -L/usr/lib /usr/lib/libecore_x.so -L/usr/X11R6/lib /usr/lib/libImlib2.so  -march=i686 -Wl,-soname -Wl,libesmart_trans_x11.so.0 -o .libs/libesmart_trans_x11.so.0.0.9
(cd .libs && rm -f libesmart_trans_x11.so.0 && ln -s libesmart_trans_x11.so.0.0.9 libesmart_trans_x11.so.0)
(cd .libs && rm -f libesmart_trans_x11.so && ln -s libesmart_trans_x11.so.0.0.9 libesmart_trans_x11.so)
i686-pc-linux-gnu-ar cru .libs/libesmart_trans_x11.a  esmart_trans_x11.o
i686-pc-linux-gnu-ranlib .libs/libesmart_trans_x11.a
creating libesmart_trans_x11.la
(cd .libs && rm -f libesmart_trans_x11.la && ln -s ../libesmart_trans_x11.la libesmart_trans_x11.la)
make[4]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_trans_x11'
Making all in esmart_resize
make[4]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_resize'
/bin/sh ../../../libtool --tag=CC   --mode=compile i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_resize     -march=i686 -O2 -pipe -Wall  -MT esmart_resize.lo -MD -MP -MF .deps/esmart_resize.Tpo -c -o esmart_resize.lo esmart_resize.c
mkdir .libs
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_resize -march=i686 -O2 -pipe -Wall -MT esmart_resize.lo -MD -MP -MF .deps/esmart_resize.Tpo -c esmart_resize.c  -fPIC -DPIC -o .libs/esmart_resize.o
 i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../../src -I../../../src/lib/esmart_resize -march=i686 -O2 -pipe -Wall -MT esmart_resize.lo -MD -MP -MF .deps/esmart_resize.Tpo -c esmart_resize.c -o esmart_resize.o >/dev/null 2>&1
mv -f .deps/esmart_resize.Tpo .deps/esmart_resize.Plo
/bin/sh ../../../libtool --tag=CC   --mode=link i686-pc-linux-gnu-gcc  -march=i686 -O2 -pipe -Wall  -lecore_evas -lecore -levas -lecore_x   -version-info 0:9:0  -o libesmart_resize.la -rpath /usr/lib esmart_resize.lo
i686-pc-linux-gnu-gcc -shared  .libs/esmart_resize.o  /usr/lib/libecore_evas.so -L/usr/lib -L/usr/X11R6/lib /usr/lib/libecore.so /usr/lib/libevas.so /usr/lib/libecore_x.so  -march=i686 -Wl,-soname -Wl,libesmart_resize.so.0 -o .libs/libesmart_resize.so.0.0.9
(cd .libs && rm -f libesmart_resize.so.0 && ln -s libesmart_resize.so.0.0.9 libesmart_resize.so.0)
(cd .libs && rm -f libesmart_resize.so && ln -s libesmart_resize.so.0.0.9 libesmart_resize.so)
i686-pc-linux-gnu-ar cru .libs/libesmart_resize.a  esmart_resize.o
i686-pc-linux-gnu-ranlib .libs/libesmart_resize.a
creating libesmart_resize.la
(cd .libs && rm -f libesmart_resize.la && ln -s ../libesmart_resize.la libesmart_resize.la)
make[4]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib/esmart_resize'
make[4]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib'
make[4]: Nothing to be done for `all-am'.
make[4]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib'
make[3]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/lib'
Making all in bin
make[3]: Entering directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/bin'
i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../src    -I../../src/lib -I../../src/lib/esmart_thumb -I../../src/lib/esmart_container -I../../src/lib/esmart_trans_x11 -I../../src/lib/esmart_draggies -I../../src/lib/esmart_text_entry -I../../src/lib/esmart_file_dialog  -march=i686 -O2 -pipe -Wall  -MT esmart_test.o -MD -MP -MF .deps/esmart_test.Tpo -c -o esmart_test.o esmart_test.c
mv -f .deps/esmart_test.Tpo .deps/esmart_test.Po
/bin/sh ../../libtool --tag=CC   --mode=link i686-pc-linux-gnu-gcc -I../../src/lib -I../../src/lib/esmart_thumb -I../../src/lib/esmart_container -I../../src/lib/esmart_trans_x11 -I../../src/lib/esmart_draggies -I../../src/lib/esmart_text_entry -I../../src/lib/esmart_file_dialog  -march=i686 -O2 -pipe -Wall    -o esmart_test esmart_test.o ../../src/lib/esmart_container/libesmart_container.la ../../src/lib/esmart_draggies/libesmart_draggies.la ../../src/lib/esmart_thumb/libesmart_thumb.la ../../src/lib/esmart_trans_x11/libesmart_trans_x11.la -levas   -levas -lImlib2 -lepsilon
mkdir .libs
i686-pc-linux-gnu-gcc -I../../src/lib -I../../src/lib/esmart_thumb -I../../src/lib/esmart_container -I../../src/lib/esmart_trans_x11 -I../../src/lib/esmart_draggies -I../../src/lib/esmart_text_entry -I../../src/lib/esmart_file_dialog -march=i686 -O2 -pipe -Wall -o .libs/esmart_test esmart_test.o  ../../src/lib/esmart_container/.libs/libesmart_container.so /usr/lib/libltdl.so ../../src/lib/esmart_draggies/.libs/libesmart_draggies.so -L/usr/X11R6/lib ../../src/lib/esmart_thumb/.libs/libesmart_thumb.so ../../src/lib/esmart_trans_x11/.libs/libesmart_trans_x11.so /usr/lib/libepsilon.so /usr/lib/libImlib2.so /usr/lib/libepeg.so /usr/lib/libpng12.so /usr/lib/libecore_file.so /usr/lib/libecore_con.so -lssl -lcrypto /usr/lib/libedje.so /usr/lib/libecore_evas.so /usr/lib/libecore_directfb.so /usr/lib/libdirectfb.so /usr/lib/libfusion.so /usr/lib/libdirect.so -lpthread /usr/lib/libecore_x.so /usr/lib/libXcursor.so /usr/lib/libXdamage.so /usr/lib/libXfixes.so /usr/lib/libXinerama.so /usr/lib/libXp.so /usr/lib/libXrandr.so /usr/lib/libXrender.so /usr/lib/libXss.so /usr/lib/libXext.so /usr/lib/libX11.so /usr/lib/libXau.so /usr/lib/libXdmcp.so /usr/lib/libecore_txt.so /usr/lib/libecore_job.so /usr/lib/libecore.so /usr/lib/libembryo.so /usr/lib/libevas.so /usr/lib/libeet.so /usr/lib/libjpeg.so /usr/lib/libfontconfig.so /usr/lib/libfreetype.so /usr/lib/libxml2.so -ldl -lz -lm
creating esmart_test
i686-pc-linux-gnu-gcc -DHAVE_CONFIG_H -I. -I../../src    -I../../src/lib -I../../src/lib/esmart_thumb -I../../src/lib/esmart_container -I../../src/lib/esmart_trans_x11 -I../../src/lib/esmart_draggies -I../../src/lib/esmart_text_entry -I../../src/lib/esmart_file_dialog  -march=i686 -O2 -pipe -Wall  -MT esmart_file_dialog_test.o -MD -MP -MF .deps/esmart_file_dialog_test.Tpo -c -o esmart_file_dialog_test.o esmart_file_dialog_test.c
mv -f .deps/esmart_file_dialog_test.Tpo .deps/esmart_file_dialog_test.Po
make[3]: *** No rule to make target `../../src/lib/esmart_file_dialog/libesmart_file_dialog.la', needed by `esmart_file_dialog_test'.  Stop.
make[3]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src/bin'
make[2]: *** [all-recursive] Error 1
make[2]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src'
make[1]: *** [all] Error 2
make[1]: Leaving directory `/var/tmp/portage/x11-libs/esmart-9999/work/e17/libs/esmart/src'
make: *** [all-recursive] Error 1